(api)=

# API Reference

:::{seealso}
For granular control see the [libvcs documentation](https://libvcs.git-pull.com/en/latest/)---especially the sections on [commands](https://libvcs.git-pull.com/en/latest/usage/commands.html) and [projects](https://libvcs.git-pull.com/en/latest/usage/projects.html).
:::

::::{grid} 1 2 3 3
:gutter: 2 2 3 3

:::{grid-item-card} vcspull.config
:link: config
:link-type: doc
Configuration loading and repo extraction.
:::

:::{grid-item-card} vcspull.exc
:link: exc
:link-type: doc
Exception hierarchy.
:::

:::{grid-item-card} vcspull.log
:link: log
:link-type: doc
Logging helpers.
:::

:::{grid-item-card} vcspull.validator
:link: validator
:link-type: doc
Config validation utilities.
:::

:::{grid-item-card} vcspull.util
:link: util
:link-type: doc
General-purpose utilities.
:::

:::{grid-item-card} vcspull.types
:link: types
:link-type: doc
Type definitions and aliases.
:::

::::

```{toctree}
:hidden:

config
exc
log
validator
util
types
```
